@@ -7,6 +7,21 @@ import (
 	"github.com/rs/zerolog"
 )
 
+// A SourceDirTargetType is the type of a target represented by a directory in
+// the source state.
+type SourceDirTargetType int
+
+// Source dir types.
+const (
+	SourceDirTypeDir SourceDirTargetType = iota
+	SourceDirTypeRemove
+)
+
+var sourceDirTypeStrs = map[SourceDirTargetType]string{
+	SourceDirTypeDir:    "dir",
+	SourceDirTypeRemove: "remove",
+}
+
 // A SourceFileTargetType is a the type of a target represented by a file in the
 // source state. A file in the source state can represent a file, script, or
 // symlink in the target state.
@@ -55,11 +70,11 @@ const (
 // DirAttr holds attributes parsed from a source directory name.
 type DirAttr struct {
 	TargetName string
+	Type       SourceDirTargetType
 	Exact      bool
 	External   bool
 	Private    bool
 	ReadOnly   bool
-	Remove     bool
 }
 
 // A FileAttr holds attributes parsed from a source file name.
@@ -78,12 +93,24 @@ type FileAttr struct {
 
 // parseDirAttr parses a single directory name in the source state.
 func parseDirAttr(sourceName string) DirAttr {
-	name := sourceName
-	name, external := CutPrefix(name, externalPrefix)
-	name, remove := CutPrefix(name, removePrefix)
-	name, exact := CutPrefix(name, exactPrefix)
-	name, private := CutPrefix(name, privatePrefix)
-	name, readOnly := CutPrefix(name, readOnlyPrefix)
+	var (
+		sourceDirType = SourceDirTypeDir
+		name          = sourceName
+		external      = false
+		exact         = false
+		private       = false
+		readOnly      = false
+	)
+	switch {
+	case strings.HasPrefix(name, removePrefix):
+		sourceDirType = SourceDirTypeRemove
+		name = name[len(removePrefix):]
+	default:
+		name, external = CutPrefix(name, externalPrefix)
+		name, exact = CutPrefix(name, exactPrefix)
+		name, private = CutPrefix(name, privatePrefix)
+		name, readOnly = CutPrefix(name, readOnlyPrefix)
+	}
 	switch {
 	case strings.HasPrefix(name, dotPrefix):
 		name = "." + name[len(dotPrefix):]
@@ -92,43 +119,45 @@ func parseDirAttr(sourceName string) DirAttr {
 	}
 	return DirAttr{
 		TargetName: name,
+		Type:       sourceDirType,
 		Exact:      exact,
 		External:   external,
 		Private:    private,
 		ReadOnly:   readOnly,
-		Remove:     remove,
 	}
 }
 
 // MarshalZerologObject implements
 // github.com/rs/zerolog.ObjectMarshaler.MarshalZerologObject.
 func (da DirAttr) MarshalZerologObject(e *zerolog.Event) {
-	e.Str("targetName", da.TargetName)
-	e.Bool("exact", da.Exact)
-	e.Bool("external", da.External)
-	e.Bool("private", da.Private)
-	e.Bool("readOnly", da.ReadOnly)
-	e.Bool("remove", da.Remove)
+	e.Str("TargetName", da.TargetName)
+	e.Str("Type", sourceDirTypeStrs[da.Type])
+	e.Bool("Exact", da.Exact)
+	e.Bool("External", da.External)
+	e.Bool("Private", da.Private)
+	e.Bool("ReadOnly", da.ReadOnly)
 }
 
 // SourceName returns da's source name.
 func (da DirAttr) SourceName() string {
 	sourceName := ""
-	if da.External {
-		sourceName += externalPrefix
-	}
-	if da.Remove {
+	switch da.Type {
+	case SourceDirTypeDir:
+		if da.External {
+			sourceName += externalPrefix
+		}
+		if da.Exact {
+			sourceName += exactPrefix
+		}
+		if da.Private {
+			sourceName += privatePrefix
+		}
+		if da.ReadOnly {
+			sourceName += readOnlyPrefix
+		}
+	case SourceDirTypeRemove:
 		sourceName += removePrefix
 	}
-	if da.Exact {
-		sourceName += exactPrefix
-	}
-	if da.Private {
-		sourceName += privatePrefix
-	}
-	if da.ReadOnly {
-		sourceName += readOnlyPrefix
-	}
 	switch {
 	case strings.HasPrefix(da.TargetName, "."):
 		sourceName += dotPrefix + da.TargetName[len("."):]
@@ -173,6 +202,7 @@ func parseFileAttr(sourceName, encryptedSuffix string) FileAttr {
 		name, encrypted = CutPrefix(name, encryptedPrefix)
 		name, private = CutPrefix(name, privatePrefix)
 		name, readOnly = CutPrefix(name, readOnlyPrefix)
+		name, empty = CutPrefix(name, emptyPrefix)
 		name, executable = CutPrefix(name, executablePrefix)
 	case strings.HasPrefix(name, removePrefix):
 		sourceFileType = SourceFileTypeRemove
@@ -276,6 +306,9 @@ func (fa FileAttr) SourceName(encryptedSuffix string) string {
 		if fa.ReadOnly {
 			sourceName += readOnlyPrefix
 		}
+		if fa.Empty {
+			sourceName += emptyPrefix
+		}
 		if fa.Executable {
 			sourceName += executablePrefix
 		}
