@@ -4,8 +4,7 @@ import (
 	"os"
 	"testing"
 
-	"github.com/stretchr/testify/assert"
-	"github.com/stretchr/testify/require"
+	"github.com/alecthomas/assert/v2"
 	"github.com/twpayne/go-vfs/v4"
 	"github.com/twpayne/go-vfs/v4/vfst"
 
@@ -25,12 +24,12 @@ func TestBoltPersistentState(t *testing.T) {
 		)
 
 		b1, err := NewBoltPersistentState(system, path, BoltPersistentStateReadWrite)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 
 		// Test that getting a key from an non-existent state does not create
 		// the state.
 		actualValue, err := b1.Get(bucket, key)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		vfst.RunTests(t, fileSystem, "",
 			vfst.TestPath(path.String(),
 				vfst.TestDoesNotExist,
@@ -40,7 +39,7 @@ func TestBoltPersistentState(t *testing.T) {
 
 		// Test that deleting a key from a non-existent state does not create
 		// the state.
-		require.NoError(t, b1.Delete(bucket, key))
+		assert.NoError(t, b1.Delete(bucket, key))
 		vfst.RunTests(t, fileSystem, "",
 			vfst.TestPath(path.String(),
 				vfst.TestDoesNotExist,
@@ -55,35 +54,35 @@ func TestBoltPersistentState(t *testing.T) {
 			),
 		)
 		actualValue, err = b1.Get(bucket, key)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		assert.Equal(t, value, actualValue)
 
 		visited := false
-		require.NoError(t, b1.ForEach(bucket, func(k, v []byte) error {
+		assert.NoError(t, b1.ForEach(bucket, func(k, v []byte) error {
 			visited = true
 			assert.Equal(t, key, k)
 			assert.Equal(t, value, v)
 			return nil
 		}))
-		require.True(t, visited)
+		assert.True(t, visited)
 
 		data, err := b1.Data()
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		assert.Equal(t, map[string]map[string]string{
 			string(bucket): {
 				string(key): string(value),
 			},
-		}, data)
+		}, data.(map[string]map[string]string))
 
-		require.NoError(t, b1.Close())
+		assert.NoError(t, b1.Close())
 
 		b2, err := NewBoltPersistentState(system, path, BoltPersistentStateReadWrite)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 
-		require.NoError(t, b2.Delete(bucket, key))
+		assert.NoError(t, b2.Delete(bucket, key))
 
 		actualValue, err = b2.Get(bucket, key)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		assert.Equal(t, []byte(nil), actualValue)
 	})
 }
@@ -100,33 +99,33 @@ func TestBoltPersistentStateMock(t *testing.T) {
 		)
 
 		b, err := NewBoltPersistentState(system, path, BoltPersistentStateReadWrite)
-		require.NoError(t, err)
-		require.NoError(t, b.Set(bucket, key, value1))
+		assert.NoError(t, err)
+		assert.NoError(t, b.Set(bucket, key, value1))
 
 		m := NewMockPersistentState()
-		require.NoError(t, b.CopyTo(m), err)
+		assert.NoError(t, b.CopyTo(m), err)
 
 		actualValue, err := m.Get(bucket, key)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		assert.Equal(t, value1, actualValue)
 
-		require.NoError(t, m.Set(bucket, key, value2))
+		assert.NoError(t, m.Set(bucket, key, value2))
 		actualValue, err = m.Get(bucket, key)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		assert.Equal(t, value2, actualValue)
 		actualValue, err = b.Get(bucket, key)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		assert.Equal(t, value1, actualValue)
 
-		require.NoError(t, m.Delete(bucket, key))
+		assert.NoError(t, m.Delete(bucket, key))
 		actualValue, err = m.Get(bucket, key)
-		require.NoError(t, err)
-		assert.Nil(t, actualValue)
+		assert.NoError(t, err)
+		assert.Zero(t, actualValue)
 		actualValue, err = b.Get(bucket, key)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		assert.Equal(t, value1, actualValue)
 
-		require.NoError(t, b.Close())
+		assert.NoError(t, b.Close())
 	})
 }
 
@@ -140,9 +139,9 @@ func TestBoltPersistentStateGeneric(t *testing.T) {
 	}()
 	testPersistentState(t, func() PersistentState {
 		tempDir, err := os.MkdirTemp("", "chezmoi-test")
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		b, err := NewBoltPersistentState(system, NewAbsPath(tempDir).JoinString("chezmoistate.boltdb"), BoltPersistentStateReadWrite)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		return b
 	})
 }
@@ -158,34 +157,34 @@ func TestBoltPersistentStateReadOnly(t *testing.T) {
 		)
 
 		b1, err := NewBoltPersistentState(system, path, BoltPersistentStateReadWrite)
-		require.NoError(t, err)
-		require.NoError(t, b1.Set(bucket, key, value))
-		require.NoError(t, b1.Close())
+		assert.NoError(t, err)
+		assert.NoError(t, b1.Set(bucket, key, value))
+		assert.NoError(t, b1.Close())
 
 		b2, err := NewBoltPersistentState(system, path, BoltPersistentStateReadOnly)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		defer func() {
 			assert.NoError(t, b2.Close())
 		}()
 
 		b3, err := NewBoltPersistentState(system, path, BoltPersistentStateReadOnly)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		defer func() {
 			assert.NoError(t, b3.Close())
 		}()
 
 		actualValueB, err := b2.Get(bucket, key)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		assert.Equal(t, value, actualValueB)
 
 		actualValueC, err := b3.Get(bucket, key)
-		require.NoError(t, err)
+		assert.NoError(t, err)
 		assert.Equal(t, value, actualValueC)
 
 		assert.Error(t, b2.Set(bucket, key, value))
 		assert.Error(t, b3.Set(bucket, key, value))
 
-		require.NoError(t, b2.Close())
-		require.NoError(t, b3.Close())
+		assert.NoError(t, b2.Close())
+		assert.NoError(t, b3.Close())
 	})
 }
