@@ -911,7 +911,7 @@ func (s *SourceState) Read(ctx context.Context, options *ReadOptions) error {
 				allSourceStateEntriesMu.Unlock()
 				return fs.SkipDir
 			}
-			if sourceStateDir.Attr.Remove {
+			if sourceStateDir.Attr.Type == SourceDirTypeRemove {
 				s.Lock()
 				s.removeDirs[targetRelPath] = struct{}{}
 				s.Unlock()
@@ -1537,7 +1537,7 @@ func (s *SourceState) newCreateTargetStateEntryFunc(
 		}
 		return &TargetStateFile{
 			lazyContents: lazyContents,
-			empty:        true,
+			empty:        fileAttr.Empty,
 			perm:         fileAttr.perm() &^ s.umask,
 			sourceAttr: SourceAttr{
 				Encrypted: fileAttr.Encrypted,
